# Changelog

## 1.11.0 (2025-06-06)

Full Changelog: [v1.10.0...v1.11.0](https://github.com/Avido-AI/avido-py/compare/v1.10.0...v1.11.0)

### Features

* **api:** manual updates ([da3e594](https://github.com/Avido-AI/avido-py/commit/da3e594e01c960192b360afc51d2a4c0fe2ac4f0))
* **client:** add follow_redirects request option ([86d75a7](https://github.com/Avido-AI/avido-py/commit/86d75a7e7efe08cdacd012d2bd4e29dd717a0ff4))


### Chores

* **docs:** remove reference to rye shell ([22ca6cf](https://github.com/Avido-AI/avido-py/commit/22ca6cf9b70110be1364a1ed96a4ee38e8fe1a0a))

## 1.10.0 (2025-05-30)

Full Changelog: [v1.9.2...v1.10.0](https://github.com/Avido-AI/avido-py/compare/v1.9.2...v1.10.0)

### Features

* **api:** documents ([628763d](https://github.com/Avido-AI/avido-py/commit/628763d0267061c21a22ce842b3b5a4a8b9312d1))
* **api:** manual updates ([e30c79c](https://github.com/Avido-AI/avido-py/commit/e30c79c69fece35cae2e7b5a6f0859facf834a40))


### Chores

* Auto updates from Stainless ([98dbdaf](https://github.com/Avido-AI/avido-py/commit/98dbdaf9baefb60848e1c92c3df6c1a1daf4a4a1))
* Auto updates from Stainless ([b1440ea](https://github.com/Avido-AI/avido-py/commit/b1440ea82f0e85ef41bb373d8ad623f0e580b395))
* Auto updates from Stainless ([327fcc5](https://github.com/Avido-AI/avido-py/commit/327fcc546484cd5e9d1b7cba0ce9e653ae0d17dd))
* **ci:** fix installation instructions ([c876a19](https://github.com/Avido-AI/avido-py/commit/c876a190c3eaeb694ec14c98ac6231fb61a4820e))
* **docs:** grammar improvements ([365542c](https://github.com/Avido-AI/avido-py/commit/365542c1d57f8566d1520bf1f40f697268ace6b8))

## 1.9.2 (2025-05-15)

Full Changelog: [v1.9.1...v1.9.2](https://github.com/Avido-AI/avido-py/compare/v1.9.1...v1.9.2)

### Chores

* Auto updates from Stainless ([933d440](https://github.com/Avido-AI/avido-py/commit/933d4403a48150e04018ea010b30ee2515e02805))

## 1.9.1 (2025-05-15)

Full Changelog: [v1.9.0...v1.9.1](https://github.com/Avido-AI/avido-py/compare/v1.9.0...v1.9.1)

### Bug Fixes

* **package:** support direct resource imports ([f462d31](https://github.com/Avido-AI/avido-py/commit/f462d31182a0691d7181522824b0973e94e3a659))
* **perf:** optimize some hot paths ([edbe209](https://github.com/Avido-AI/avido-py/commit/edbe2097427843c905c7217efe507f194ef05215))
* **perf:** skip traversing types for NotGiven values ([c896aee](https://github.com/Avido-AI/avido-py/commit/c896aeeee6cfe27c4eb6b42b7d02c2951b2cfacc))
* **pydantic v1:** more robust ModelField.annotation check ([1f5f64d](https://github.com/Avido-AI/avido-py/commit/1f5f64d4f94ce2594861103a72d31c7d20998f95))


### Chores

* Auto updates from Stainless ([89c0c6c](https://github.com/Avido-AI/avido-py/commit/89c0c6c4cd7cbf8ffc0d55808aaad59cb57d4125))
* Auto updates from Stainless ([a862c7f](https://github.com/Avido-AI/avido-py/commit/a862c7f35c5afef1ee099632b02e1e5e81fae00e))
* Auto updates from Stainless ([251078a](https://github.com/Avido-AI/avido-py/commit/251078ae8f2e2ea9a1e40237c1840f118b339a42))
* Auto updates from Stainless ([7fdae91](https://github.com/Avido-AI/avido-py/commit/7fdae91ade4fb72e300cff5b197501006df7e0e6))
* broadly detect json family of content-type headers ([ce65adf](https://github.com/Avido-AI/avido-py/commit/ce65adfc1f842bca52cae8d51b4ce821088b53f2))
* **ci:** add timeout thresholds for CI jobs ([e374f9a](https://github.com/Avido-AI/avido-py/commit/e374f9a651c3dae72327fc80bdb3596a0d2285cc))
* **ci:** only use depot for staging repos ([1bdca53](https://github.com/Avido-AI/avido-py/commit/1bdca53655dccd2f311fd3b6318fac0a7ab3e986))
* **ci:** upload sdks to package manager ([bdc8ae7](https://github.com/Avido-AI/avido-py/commit/bdc8ae7ae2e7be0535e75c8c7f7cf997f86d61ec))
* **client:** minor internal fixes ([e40a715](https://github.com/Avido-AI/avido-py/commit/e40a715514b7275af50f9f9f2d0670c005c7ff29))
* **internal:** avoid errors for isinstance checks on proxies ([1a43c56](https://github.com/Avido-AI/avido-py/commit/1a43c56a48caf932e7d1222d5aee3ef430ac088a))
* **internal:** avoid lint errors in pagination expressions ([724d36d](https://github.com/Avido-AI/avido-py/commit/724d36dfa32c1f7632e03f5963f2b0a0a2f505fe))
* **internal:** base client updates ([0821b79](https://github.com/Avido-AI/avido-py/commit/0821b7957b9f70204faadb64dd0a4d574c543387))
* **internal:** bump pyright version ([b4b7cf5](https://github.com/Avido-AI/avido-py/commit/b4b7cf59cd26f15b741f7351365b03676c5b5849))
* **internal:** codegen related update ([ebfaa43](https://github.com/Avido-AI/avido-py/commit/ebfaa43424112d329a51a5f649e676a82f5c0d91))
* **internal:** codegen related update ([378c99e](https://github.com/Avido-AI/avido-py/commit/378c99e1b952bb88006b54c4d28c06d8920472fe))
* **internal:** expand CI branch coverage ([34c21e3](https://github.com/Avido-AI/avido-py/commit/34c21e335172197dbc1b051aa46865d473070ea3))
* **internal:** fix list file params ([ff03e6e](https://github.com/Avido-AI/avido-py/commit/ff03e6e90ad348e939d762da2cf901082872cc11))
* **internal:** import reformatting ([e717e90](https://github.com/Avido-AI/avido-py/commit/e717e90bff5b53535e7d211761186219b4215372))
* **internal:** minor formatting changes ([b750060](https://github.com/Avido-AI/avido-py/commit/b75006025f6ff99b5424f96ec70c45693b667e6f))
* **internal:** reduce CI branch coverage ([368e4ad](https://github.com/Avido-AI/avido-py/commit/368e4adcae0a8eefe4baa6ab7858c8f744643961))
* **internal:** refactor retries to not use recursion ([150f5ac](https://github.com/Avido-AI/avido-py/commit/150f5acaea474cce30eea8255eccf5b4418ff772))
* **internal:** update models test ([98ba007](https://github.com/Avido-AI/avido-py/commit/98ba0076e88158c7fd73d3c38558067f915667a6))
* **internal:** update pyright settings ([7e0bc76](https://github.com/Avido-AI/avido-py/commit/7e0bc7630179236f3bfa17838889f299f4e6b7db))

## 1.9.0 (2025-04-09)

Full Changelog: [v1.8.0...v1.9.0](https://github.com/Avido-AI/avido-py/compare/v1.8.0...v1.9.0)

### Features

* **api:** authentication ([#101](https://github.com/Avido-AI/avido-py/issues/101)) ([082b9ea](https://github.com/Avido-AI/avido-py/commit/082b9ea048a3a650fbed881f63622fd042cb2e3d))
* **api:** manual updates ([#90](https://github.com/Avido-AI/avido-py/issues/90)) ([dc437e6](https://github.com/Avido-AI/avido-py/commit/dc437e6831340b64192df83de0d8845ed99ab909))
* **api:** manual updates ([#91](https://github.com/Avido-AI/avido-py/issues/91)) ([134c10b](https://github.com/Avido-AI/avido-py/commit/134c10b9fd49115d118a1deea2ae382ddc555081))


### Bug Fixes

* **ci:** ensure pip is always available ([#88](https://github.com/Avido-AI/avido-py/issues/88)) ([1b5b558](https://github.com/Avido-AI/avido-py/commit/1b5b558de6e54c28afb52d5d1c21c208a2f3876b))
* **ci:** remove publishing patch ([#89](https://github.com/Avido-AI/avido-py/issues/89)) ([d260eb3](https://github.com/Avido-AI/avido-py/commit/d260eb3ce90c994a49857f4d1b1f8e6caf9d4ee4))
* **client:** send all configured auth headers ([#95](https://github.com/Avido-AI/avido-py/issues/95)) ([b089939](https://github.com/Avido-AI/avido-py/commit/b0899397b2cca27253a056da528757b1ba5fcdc7))
* **types:** handle more discriminated union shapes ([#87](https://github.com/Avido-AI/avido-py/issues/87)) ([ee18be8](https://github.com/Avido-AI/avido-py/commit/ee18be8c556c86092e7fcd57ff56690f2f72ce15))


### Chores

* Auto updates from Stainless ([#100](https://github.com/Avido-AI/avido-py/issues/100)) ([5e8e825](https://github.com/Avido-AI/avido-py/commit/5e8e825d16eec5576bf8a1717653379f39d6e247))
* Auto updates from Stainless ([#92](https://github.com/Avido-AI/avido-py/issues/92)) ([19b306d](https://github.com/Avido-AI/avido-py/commit/19b306d91dc95e0b8f459ba45d92fa1a84d0609f))
* Auto updates from Stainless ([#93](https://github.com/Avido-AI/avido-py/issues/93)) ([38e0b74](https://github.com/Avido-AI/avido-py/commit/38e0b7481ed210df7dca09ca7b04428bcc0aa169))
* **internal:** codegen related update ([#85](https://github.com/Avido-AI/avido-py/issues/85)) ([f985244](https://github.com/Avido-AI/avido-py/commit/f985244b0c502acb6a87b7ec9096334ca5cafd88))
* **internal:** codegen related update ([#86](https://github.com/Avido-AI/avido-py/issues/86)) ([9a52b92](https://github.com/Avido-AI/avido-py/commit/9a52b92bf602e6763af3d26dfb343ba66950c42c))
* **internal:** codegen related update ([#96](https://github.com/Avido-AI/avido-py/issues/96)) ([3745f43](https://github.com/Avido-AI/avido-py/commit/3745f430af9f1364d7ec336f727a1664c529b63d))
* **internal:** codegen related update ([#97](https://github.com/Avido-AI/avido-py/issues/97)) ([c2a72ed](https://github.com/Avido-AI/avido-py/commit/c2a72ed2cc87950cdc1aea2f7d9773501c8e1fc5))
* **internal:** remove extra empty newlines ([#83](https://github.com/Avido-AI/avido-py/issues/83)) ([0785de6](https://github.com/Avido-AI/avido-py/commit/0785de64fc4d84760ce2dff8f0dc24ed54976bc1))
* **internal:** remove trailing character ([#94](https://github.com/Avido-AI/avido-py/issues/94)) ([f41d870](https://github.com/Avido-AI/avido-py/commit/f41d870550441a3f4be08f5f8e071b275f5bc0fd))
* **internal:** slight transform perf improvement ([#98](https://github.com/Avido-AI/avido-py/issues/98)) ([dd5eb35](https://github.com/Avido-AI/avido-py/commit/dd5eb35be9f189fc88b582bc6e15a62e89f4ee26))
* **tests:** improve enum examples ([#99](https://github.com/Avido-AI/avido-py/issues/99)) ([0fc7ed9](https://github.com/Avido-AI/avido-py/commit/0fc7ed93e39af0eaa6fbff82ddf0f67396595d4e))

## 1.8.0 (2025-03-12)

Full Changelog: [v1.7.0...v1.8.0](https://github.com/Avido-AI/avido-py/compare/v1.7.0...v1.8.0)

### Features

* **api:** manual updates ([#81](https://github.com/Avido-AI/avido-py/issues/81)) ([43e48ed](https://github.com/Avido-AI/avido-py/commit/43e48ede5f9187eedf4877473c2163fcea853d23))


### Chores

* Auto updates from Stainless ([#79](https://github.com/Avido-AI/avido-py/issues/79)) ([578c736](https://github.com/Avido-AI/avido-py/commit/578c7368871babb40340c8f99700212904a4c1d7))

## 1.7.0 (2025-03-11)

Full Changelog: [v1.6.0...v1.7.0](https://github.com/Avido-AI/avido-py/compare/v1.6.0...v1.7.0)

### Features

* **api:** manual updates ([#76](https://github.com/Avido-AI/avido-py/issues/76)) ([3eec582](https://github.com/Avido-AI/avido-py/commit/3eec582307c14252ae170274077d507780d7ce50))


### Chores

* Auto updates from Stainless ([#77](https://github.com/Avido-AI/avido-py/issues/77)) ([dc90586](https://github.com/Avido-AI/avido-py/commit/dc90586ba1e759db55c19ab24208cfa522543464))

## 1.6.0 (2025-03-04)

Full Changelog: [v1.5.1...v1.6.0](https://github.com/Avido-AI/avido-py/compare/v1.5.1...v1.6.0)

### Features

* **client:** allow passing `NotGiven` for body ([#67](https://github.com/Avido-AI/avido-py/issues/67)) ([dbff040](https://github.com/Avido-AI/avido-py/commit/dbff040aab650794b2b187f54aab6a7eed330c1f))
* **client:** send `X-Stainless-Read-Timeout` header ([#61](https://github.com/Avido-AI/avido-py/issues/61)) ([f3d5ada](https://github.com/Avido-AI/avido-py/commit/f3d5adaa193bbdd6bb46e503b6766c8098032063))


### Bug Fixes

* asyncify on non-asyncio runtimes ([#66](https://github.com/Avido-AI/avido-py/issues/66)) ([f06cec7](https://github.com/Avido-AI/avido-py/commit/f06cec7977861737134ca08c1f2ac8ea7f6174ba))
* **client:** mark some request bodies as optional ([dbff040](https://github.com/Avido-AI/avido-py/commit/dbff040aab650794b2b187f54aab6a7eed330c1f))


### Chores

* **docs:** update client docstring ([#71](https://github.com/Avido-AI/avido-py/issues/71)) ([95a18c9](https://github.com/Avido-AI/avido-py/commit/95a18c920783118be874cbe508d74a37a85a7699))
* **internal:** bummp ruff dependency ([#60](https://github.com/Avido-AI/avido-py/issues/60)) ([138796d](https://github.com/Avido-AI/avido-py/commit/138796d10b29fbcb5e9c2fdcedd82e37a730494b))
* **internal:** change default timeout to an int ([#59](https://github.com/Avido-AI/avido-py/issues/59)) ([a064a7e](https://github.com/Avido-AI/avido-py/commit/a064a7edbfa07b104b2f53ecfcdf034003fc0d78))
* **internal:** fix devcontainers setup ([#68](https://github.com/Avido-AI/avido-py/issues/68)) ([dc46c93](https://github.com/Avido-AI/avido-py/commit/dc46c9399295be7459af1171044e697690e4400e))
* **internal:** fix type traversing dictionary params ([#62](https://github.com/Avido-AI/avido-py/issues/62)) ([a0ce66b](https://github.com/Avido-AI/avido-py/commit/a0ce66bc6c2884d7cd567c1b41aa4fb47f592b95))
* **internal:** minor formatting changes ([#57](https://github.com/Avido-AI/avido-py/issues/57)) ([88270e7](https://github.com/Avido-AI/avido-py/commit/88270e75c1cedde3a2fb3fecff44cf0a7654b770))
* **internal:** minor type handling changes ([#63](https://github.com/Avido-AI/avido-py/issues/63)) ([a8487ba](https://github.com/Avido-AI/avido-py/commit/a8487ba24b4618d28ec6ec8023a71d2626dce071))
* **internal:** properly set __pydantic_private__ ([#69](https://github.com/Avido-AI/avido-py/issues/69)) ([8efa58f](https://github.com/Avido-AI/avido-py/commit/8efa58f03391c71351f2a82c9340dc8b028a3598))
* **internal:** remove unused http client options forwarding ([#72](https://github.com/Avido-AI/avido-py/issues/72)) ([b1bea07](https://github.com/Avido-AI/avido-py/commit/b1bea076374e33c5ec34398ddfc1e3a7c0ccc909))
* **internal:** update client tests ([#65](https://github.com/Avido-AI/avido-py/issues/65)) ([d7b4efe](https://github.com/Avido-AI/avido-py/commit/d7b4efe9c16bcfda57bff6a4f834bb4754e664c3))
* minor change to tests ([#64](https://github.com/Avido-AI/avido-py/issues/64)) ([78bb432](https://github.com/Avido-AI/avido-py/commit/78bb432c55b350c8181f2de23c4c8c9141bb84c3))


### Documentation

* update URLs from stainlessapi.com to stainless.com ([#70](https://github.com/Avido-AI/avido-py/issues/70)) ([0dee5e1](https://github.com/Avido-AI/avido-py/commit/0dee5e1df4ac6d13831da1ac4d1e0d1326dfa56a))

## 1.5.1 (2025-01-23)

Full Changelog: [v1.5.0...v1.5.1](https://github.com/Avido-AI/avido-py/compare/v1.5.0...v1.5.1)

### Chores

* Auto updates from Stainless ([#55](https://github.com/Avido-AI/avido-py/issues/55)) ([fdba936](https://github.com/Avido-AI/avido-py/commit/fdba936ca349e8b910f48582601321475f817ba9))
* **internal:** codegen related update ([#51](https://github.com/Avido-AI/avido-py/issues/51)) ([1593c1f](https://github.com/Avido-AI/avido-py/commit/1593c1f362d69fc720212f2fbecfb2bf53782094))
* **internal:** codegen related update ([#53](https://github.com/Avido-AI/avido-py/issues/53)) ([d1d7801](https://github.com/Avido-AI/avido-py/commit/d1d7801b3170ad251b8429e2ff97ce62e294a36a))
* **internal:** minor style changes ([#54](https://github.com/Avido-AI/avido-py/issues/54)) ([c46fc08](https://github.com/Avido-AI/avido-py/commit/c46fc0866d3ff856dc0c86e9bcafcf4bc09757df))

## 1.5.0 (2025-01-16)

Full Changelog: [v1.4.0...v1.5.0](https://github.com/Avido-AI/avido-py/compare/v1.4.0...v1.5.0)

### Features

* **api:** manual updates ([#47](https://github.com/Avido-AI/avido-py/issues/47)) ([6548383](https://github.com/Avido-AI/avido-py/commit/6548383eacc022ffc24490bafec2d78af35aa7b6))
* **api:** manual updates ([#49](https://github.com/Avido-AI/avido-py/issues/49)) ([5f9f703](https://github.com/Avido-AI/avido-py/commit/5f9f7039988e33fa4c901b4f8976e087238564dd))


### Chores

* Auto updates from Stainless ([#45](https://github.com/Avido-AI/avido-py/issues/45)) ([a259a55](https://github.com/Avido-AI/avido-py/commit/a259a55f5e603b8665f0673131f621b96dbfbb8d))
* Auto updates from Stainless ([#48](https://github.com/Avido-AI/avido-py/issues/48)) ([3948dab](https://github.com/Avido-AI/avido-py/commit/3948dabd04d2b221f2304032f3622a05c27a4066))

## 1.4.0 (2025-01-15)

Full Changelog: [v1.3.2...v1.4.0](https://github.com/Avido-AI/avido-py/compare/v1.3.2...v1.4.0)

### Features

* **api:** manual updates ([#42](https://github.com/Avido-AI/avido-py/issues/42)) ([773476a](https://github.com/Avido-AI/avido-py/commit/773476abd23f2e1f0b050390ec8ba1e85f8f83c4))

## 1.3.2 (2025-01-14)

Full Changelog: [v1.3.1...v1.3.2](https://github.com/Avido-AI/avido-py/compare/v1.3.1...v1.3.2)

### Chores

* Auto updates from Stainless ([#39](https://github.com/Avido-AI/avido-py/issues/39)) ([9e6c6d3](https://github.com/Avido-AI/avido-py/commit/9e6c6d3bd3c2cfe20535b9a219ec46666be00e92))

## 1.3.1 (2025-01-13)

Full Changelog: [v1.3.0...v1.3.1](https://github.com/Avido-AI/avido-py/compare/v1.3.0...v1.3.1)

### Chores

* Auto updates from Stainless ([#36](https://github.com/Avido-AI/avido-py/issues/36)) ([d03084d](https://github.com/Avido-AI/avido-py/commit/d03084dbd2a571faf9910d67a5cfa6c72851db01))

## 1.3.0 (2025-01-13)

Full Changelog: [v1.2.1...v1.3.0](https://github.com/Avido-AI/avido-py/compare/v1.2.1...v1.3.0)

### Features

* **api:** manual updates ([#34](https://github.com/Avido-AI/avido-py/issues/34)) ([24c6c02](https://github.com/Avido-AI/avido-py/commit/24c6c028e60f944518d5eb465e0076c124d82944))


### Bug Fixes

* correctly handle deserialising `cls` fields ([#31](https://github.com/Avido-AI/avido-py/issues/31)) ([cf64cb6](https://github.com/Avido-AI/avido-py/commit/cf64cb6b4208c58f5d5eb4fde497ecb88b94c146))


### Chores

* Auto updates from Stainless ([#33](https://github.com/Avido-AI/avido-py/issues/33)) ([3ba6652](https://github.com/Avido-AI/avido-py/commit/3ba665229eebf61bad067d6ae12d47661c4277bc))

## 1.2.1 (2025-01-09)

Full Changelog: [v1.2.0...v1.2.1](https://github.com/Avido-AI/avido-py/compare/v1.2.0...v1.2.1)

### Bug Fixes

* **api:** better support union schemas with common properties ([#29](https://github.com/Avido-AI/avido-py/issues/29)) ([a82b662](https://github.com/Avido-AI/avido-py/commit/a82b6621fe47006d9785f272cec694c969abbc53))


### Chores

* **internal:** codegen related update ([#28](https://github.com/Avido-AI/avido-py/issues/28)) ([d154a7c](https://github.com/Avido-AI/avido-py/commit/d154a7c5e80205982fb5451598d9c617ce156348))


### Documentation

* fix typos ([#26](https://github.com/Avido-AI/avido-py/issues/26)) ([561d54c](https://github.com/Avido-AI/avido-py/commit/561d54cdff97917aaf394ea9431bd063ce8dd3b4))

## 1.2.0 (2025-01-09)

Full Changelog: [v1.1.2...v1.2.0](https://github.com/Avido-AI/avido-py/compare/v1.1.2...v1.2.0)

### Features

* **api:** manual updates ([#20](https://github.com/Avido-AI/avido-py/issues/20)) ([47278ce](https://github.com/Avido-AI/avido-py/commit/47278cee41c08b69fb5e264e57f2274598230b9c))
* **api:** manual updates ([#22](https://github.com/Avido-AI/avido-py/issues/22)) ([a900248](https://github.com/Avido-AI/avido-py/commit/a9002480c138f6dad5e28400c30884abebc0c1c4))
* **api:** manual updates ([#24](https://github.com/Avido-AI/avido-py/issues/24)) ([f9e2a37](https://github.com/Avido-AI/avido-py/commit/f9e2a37037855f0ce8341251a70f0c25f6990f13))


### Chores

* Auto updates from Stainless ([#18](https://github.com/Avido-AI/avido-py/issues/18)) ([11701d6](https://github.com/Avido-AI/avido-py/commit/11701d66996f0c79ea8a4495482716f502263e85))
* Auto updates from Stainless ([#23](https://github.com/Avido-AI/avido-py/issues/23)) ([b07dafb](https://github.com/Avido-AI/avido-py/commit/b07dafb98069279df95a9366718a5e676ac9177d))
* **internal:** version bump ([#21](https://github.com/Avido-AI/avido-py/issues/21)) ([7edecac](https://github.com/Avido-AI/avido-py/commit/7edecac1d660bf41c2239a3b0a1b52b5eb259197))

## 1.1.2 (2025-01-08)

Full Changelog: [v1.1.1...v1.1.2](https://github.com/Avido-AI/avido-py/compare/v1.1.1...v1.1.2)

### Bug Fixes

* **client:** only call .close() when needed ([#16](https://github.com/Avido-AI/avido-py/issues/16)) ([8ac068e](https://github.com/Avido-AI/avido-py/commit/8ac068e5f7f7ba594e490acaea76f70a6f62641c))

## 1.1.1 (2025-01-08)

Full Changelog: [v1.1.0...v1.1.1](https://github.com/Avido-AI/avido-py/compare/v1.1.0...v1.1.1)

### Chores

* add missing isclass check ([#12](https://github.com/Avido-AI/avido-py/issues/12)) ([04e9a0c](https://github.com/Avido-AI/avido-py/commit/04e9a0c380fc9def7bde16e79598e6196e50330b))
* **internal:** codegen related update ([#14](https://github.com/Avido-AI/avido-py/issues/14)) ([be6589a](https://github.com/Avido-AI/avido-py/commit/be6589a08f08db44983e38917aa6a575d722b7df))

## 1.1.0 (2025-01-07)

Full Changelog: [v1.0.0...v1.1.0](https://github.com/Avido-AI/avido-py/compare/v1.0.0...v1.1.0)

### Features

* **api:** manual updates ([#9](https://github.com/Avido-AI/avido-py/issues/9)) ([6cb9ff4](https://github.com/Avido-AI/avido-py/commit/6cb9ff4212a42e7c8226fa1bc44a6148bd932467))

## 1.0.0 (2025-01-06)

Full Changelog: [v0.1.0-alpha.1...v1.0.0](https://github.com/Avido-AI/avido-py/compare/v0.1.0-alpha.1...v1.0.0)

### Chores

* update SDK settings ([#6](https://github.com/Avido-AI/avido-py/issues/6)) ([7514925](https://github.com/Avido-AI/avido-py/commit/7514925d253e9c99cc6f94b054b3a085bc06eed6))

## 0.1.0-alpha.1 (2025-01-06)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/Avido-AI/avido-py/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([a8a1a3a](https://github.com/Avido-AI/avido-py/commit/a8a1a3a3ab26f5d33038e4fb32911c7030398e86))
* **api:** update via SDK Studio ([5e6cc7c](https://github.com/Avido-AI/avido-py/commit/5e6cc7cb4ccfb1bcb8f70311969319dcd087daa3))
* **api:** update via SDK Studio ([d59c381](https://github.com/Avido-AI/avido-py/commit/d59c3818a8037ea0f62f5562032fe0130bd614ab))
* **api:** update via SDK Studio ([24d4494](https://github.com/Avido-AI/avido-py/commit/24d44943efc49ae7a8effd5c0ca6ee41e2727234))
* **api:** update via SDK Studio ([fac078e](https://github.com/Avido-AI/avido-py/commit/fac078e32794c9b44e05d127906914e075293d94))
* **api:** update via SDK Studio ([4dd8dc7](https://github.com/Avido-AI/avido-py/commit/4dd8dc7e4eda290498f2e356905dc1573e0645b6))
* **api:** update via SDK Studio ([1601603](https://github.com/Avido-AI/avido-py/commit/16016038e1a8a0da4a07056a63125a7580edf94d))
* **api:** update via SDK Studio ([7893ff8](https://github.com/Avido-AI/avido-py/commit/7893ff86f62b0914e1480f27689060327c1b3c6d))
* **api:** update via SDK Studio ([0fcef05](https://github.com/Avido-AI/avido-py/commit/0fcef05a4471dfa6df21806402a1fe122cd8f0d6))
* **api:** update via SDK Studio ([a66c23c](https://github.com/Avido-AI/avido-py/commit/a66c23c7c508ebdc0110ac4fe274807d0ee2b093))
* **api:** update via SDK Studio ([dc17892](https://github.com/Avido-AI/avido-py/commit/dc178922d71b2501ef4c18ea56ce715a3d959dc5))


### Chores

* go live ([#1](https://github.com/Avido-AI/avido-py/issues/1)) ([b92b753](https://github.com/Avido-AI/avido-py/commit/b92b753e80237da9b48b76af67ee57cb1da2ecce))
* go live ([#4](https://github.com/Avido-AI/avido-py/issues/4)) ([2a7def0](https://github.com/Avido-AI/avido-py/commit/2a7def013625d8ea2b7051c9330865bb168bd9d9))
* update SDK settings ([#3](https://github.com/Avido-AI/avido-py/issues/3)) ([7cebf61](https://github.com/Avido-AI/avido-py/commit/7cebf61017cfb04a8a5b3c905c205986902ccc58))
